@@ -34,14 +34,19 @@
 #'
 #' # `str_glue_data()` is useful in data pipelines
 #' mtcars %>% str_glue_data("{rownames(.)} has {hp} hp")
-str_glue <- function(..., .sep = "", .envir = parent.frame()) {
-  glue::glue(..., .sep = .sep, .envir = .envir)
+str_glue <- function(..., .sep = "", .envir = parent.frame(), .trim = TRUE) {
+  glue::glue(..., .sep = .sep, .envir = .envir, .trim = .trim)
 }
 
 #' @export
 #' @rdname str_glue
-str_glue_data <- function(.x, ..., .sep = "", .envir = parent.frame(),
-                          .na = "NA") {
+str_glue_data <- function(
+  .x,
+  ...,
+  .sep = "",
+  .envir = parent.frame(),
+  .na = "NA"
+) {
   glue::glue_data(
     .x,
     ...,
