@@ -1,11 +1,13 @@
-#' Trim whitespace from a string
+#' Remove whitespace
 #'
 #' `str_trim()` removes whitespace from start and end of string; `str_squish()`
-#' also reduces repeated whitespace inside a string.
+#' removes whitespace at the start and end, and replaces all internal whitespace
+#' with a single space.
 #'
-#' @param string A character vector.
-#' @param side Side on which to remove whitespace (left, right or both).
-#' @return A character vector.
+#' @inheritParams str_detect
+#' @param side Side on which to remove whitespace: "left", "right", or
+#'   "both", the default.
+#' @return A character vector the same length as `string`.
 #' @export
 #' @seealso [str_pad()] to add whitespace
 #' @examples
@@ -15,17 +17,19 @@
 #' str_squish("  String with trailing,  middle, and leading white space\t")
 #' str_squish("\n\nString with excess,  trailing and leading white   space\n\n")
 str_trim <- function(string, side = c("both", "left", "right")) {
-  side <- match.arg(side)
+  side <- arg_match(side)
 
-  switch(side,
-    left =  stri_trim_left(string),
+  out <- switch(
+    side,
+    left = stri_trim_left(string),
     right = stri_trim_right(string),
-    both =  stri_trim_both(string)
+    both = stri_trim_both(string)
   )
+  copy_names(string, out)
 }
 
 #' @export
 #' @rdname str_trim
 str_squish <- function(string) {
-  stri_trim_both(str_replace_all(string,"\\s+"," "))
+  copy_names(string, stri_trim_both(str_replace_all(string, "\\s+", " ")))
 }
